[llvm-commits] CVS: llvm/include/Support/CommandLine.h

Chris Lattner lattner at cs.uiuc.edu
Thu May 6 21:27:01 PDT 2004


Changes in directory llvm/include/Support:

CommandLine.h updated: 1.30 -> 1.31

---
Log message:

Add the enum corresponding to the source change I made earlier


---
Diffs of the changes:  (+3 -2)

Index: llvm/include/Support/CommandLine.h
diff -u llvm/include/Support/CommandLine.h:1.30 llvm/include/Support/CommandLine.h:1.31
--- llvm/include/Support/CommandLine.h:1.30	Mon Feb 23 21:50:05 2004
+++ llvm/include/Support/CommandLine.h	Thu May  6 21:27:32 2004
@@ -107,8 +107,9 @@
 };
 
 enum MiscFlags {                // Miscellaneous flags to adjust argument
-  CommaSeparated   = 0x200,     // Should this cl::list split between commas?
-  MiscMask         = 0x200,
+  CommaSeparated     = 0x200,   // Should this cl::list split between commas?
+  PositionalEatsArgs = 0x400,   // Should this positional cl::list eat -args?
+  MiscMask           = 0x600,
 };
 
 





More information about the llvm-commits mailing list